@@ -602,3 +602,16 @@ class WowApi:
                 index[realm["slug"]] = connected_realm_id
 
         return index
+
+    def get_item_bonuses(self, timeout=30) -> dict:
+        """Returns a dict containing the item bonuses from raidbots.com.
+
+        Args:
+            timeout (int): How long until the request to the API timesout in seconds.
+                Default: 30 seconds.
+
+        Returns:
+             A json looking dict with nested dicts and/or lists containing data from raidbots.com
+        """
+
+        return requests.get(urls['item_bonuses']).json()
